package cn.estsh.i3plus.pojo.form.sqlpack;

import cn.estsh.i3plus.pojo.base.tool.HqlPack;
import cn.estsh.i3plus.pojo.form.bean.*;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description :
 * @Reference :
 * @Author : Adair Peng
 * @CreateDate : 2019-03-21 15:16
 * @Modify:
 **/
public final class FormHqlPack {

    private FormHqlPack() {
    }

    /**
     * In 参数封装
     * @param columnName 列名
     * @param params 参数
     * @return hql
     */
    public static String packHqlIds(String columnName, String[] params) {
        StringBuffer result =  new StringBuffer();

        // 参数数组 [1,2,3] -> "1,2,3"
        HqlPack.getInPack(String.join(",", params), columnName, result);
        return result.toString();
    }

    /**
     * In 参数封装
     * @param columnName 列名
     * @param params 参数
     * @return hql
     */
    public static String packHqlIds(String columnName, Long[] params) {
        StringBuffer result =  new StringBuffer();

        // 参数数组 [1,2,3] -> "1,2,3"
        HqlPack.getInPack(StringUtils.join(params, ","), columnName, result);
        return result.toString();
    }

    /**
     * In 参数封装
     * @param columnName 列名
     * @param params 参数
     * @param isDeleted 数据状态
     * @return hql
     */
    public static String packHqlIdsAndIsDeleted(String columnName, String[] params, Integer isDeleted) {
        StringBuffer result =  new StringBuffer(FormHqlPack.packHqlIds(columnName, params));

        HqlPack.getNumEqualPack(isDeleted, "isDeleted", result);
        return result.toString();
    }


    /**
     * In 参数封装
     * @param columnName 列名
     * @param params 参数
     * @param isDeleted 数据状态
     * @return hql
     */
    public static String packHqlIdsAndIsDeleted(String columnName, Long[] params, Integer isDeleted) {
        StringBuffer result =  new StringBuffer(FormHqlPack.packHqlIds(columnName, params));

        HqlPack.getNumEqualPack(isDeleted, "isDeleted", result);
        return result.toString();
    }

    /**
     * 表单布局复杂查询
     * @param bfLayout 表单布局
     * @return hql
     */
    public static String packHqlBfLayout(BfLayout bfLayout) {
        StringBuffer result =  new StringBuffer();

        HqlPack.getStringLikerPack(bfLayout.getLayoutName(), "layoutName", result);
        HqlPack.getNumEqualPack(bfLayout.getIsDeleted(), "isDeleted", result);

        return result.toString();
    }

    /**
     * 根据表单布局查询表单布局行
     * @param bfLayoutRow 表单布局
     * @return hql
     */
    public static String packHqlBfLayoutRow(BfLayoutRow bfLayoutRow) {
        StringBuffer result = new StringBuffer();

        HqlPack.getNumEqualPack(bfLayoutRow.getLayoutId(), "layoutId", result);
        HqlPack.getNumEqualPack(bfLayoutRow.getIsDeleted(), "isDeleted", result);

        result.append(bfLayoutRow.orderBy());
        return result.toString();
    }

    /**
     * 根据表单布局行查询表单布局列
     * @param bfLayoutColumn 表单布局行
     * @return hql
     */
    public static String packHqlBfLayoutColumn(BfLayoutColumn bfLayoutColumn) {
        StringBuffer result = new StringBuffer();

        HqlPack.getNumEqualPack(bfLayoutColumn.getLayoutRowId(), "layoutRowId", result);
        HqlPack.getNumEqualPack(bfLayoutColumn.getIsDeleted(), "isDeleted", result);

        result.append(bfLayoutColumn.orderBy());
        return result.toString();
    }

    /**
     * 菜单目录复杂查询
     * @param bfMenu 菜单目录
     * @return hql
     */
    public static String packHqlBfMenu(BfMenu bfMenu) {
        StringBuffer result =  new StringBuffer();

        HqlPack.getStringLikerPack(bfMenu.getMenuName(), "menuName", result);
        HqlPack.getNumEqualPack(bfMenu.getParentId(), "parentId", result);
        HqlPack.getNumEqualPack(bfMenu.getIsDeleted(), "isDeleted", result);
        result.append(bfMenu.orderBy());

        return result.toString();
    }

    /**
     * 表单功能复杂查询
     * @param bfMethod 表单功能查询条件
     * @return hql
     */
    public static String packHqlBfMethod(BfMethod bfMethod) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(bfMethod.getMethodName(), "methodName", result);
        HqlPack.getNumEqualPack(bfMethod.getLayoutId(), "layoutId", result);
        HqlPack.getNumEqualPack(bfMethod.getIsDeleted(), "isDeleted", result);
        result.append(bfMethod.orderBy());

        return result.toString();
    }

    /**
     * 表单拦截器复杂查询
     * @param bfIntercept 查询条件
     * @return hql
     */
    public static String packHqlBfIntercept(BfIntercept bfIntercept) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(bfIntercept.getInterceptName(), "interceptName", result);
        HqlPack.getNumEqualPack(bfIntercept.getExecuteMode(), "executeMode", result);
        HqlPack.getNumEqualPack(bfIntercept.getIsDeleted(), "isDeleted", result);
        result.append(bfIntercept.orderBy());

        return result.toString();
    }

    /**
     * 表单按钮复杂查询
     * @param bfButton 查询条件
     */
    public static String packHqlBfButton(BfButton bfButton){
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(bfButton.getButtonName(), "buttonName", result);
        HqlPack.getNumEqualPack(bfButton.getTriggerMode(), "triggerMode", result);
        HqlPack.getNumEqualPack(bfButton.getIsDeleted(), "isDeleted", result);
        result.append(bfButton.orderBy());

        return result.toString();
    }
}
